@@ -2,6 +2,7 @@ from datetime import datetime
 from unittest.mock import patch
 
 from jdatetime import datetime as jdatetime
+from pandas import DatetimeIndex
 from pytest import raises
 
 # noinspection PyProtectedMember
@@ -94,14 +95,17 @@ def test_get_page_info():
             , [48175603054578540, 'اسفراین', 'مجتمع صنعتی اسفراین']
             , [58903026391426893, 'سیرجان', 'فولاد سیرجان']
             , [68604686987554533, 'فماکح', 'ح . ماداکتو استیل کرد']]
-    assert trade_history.to_dict() == {
-        'pc': {20201021: 23990.0, 20201024: 22900.0, 20201026: 21800.0, 20201027: 20790.0, 20201028: 20580.0, 20201031: 21540.0, 20201101: 20910.0, 20201102: 20860.0, 20201104: 21900.0}
-        , 'pmax': {20201021: 24790.0, 20201024: 23730.0, 20201026: 22700.0, 20201027: 22050.0, 20201028: 21420.0, 20201031: 21600.0, 20201101: 22000.0, 20201102: 21490.0, 20201104: 21900.0}
-        , 'pmin': {20201021: 22660.0, 20201024: 22800.0, 20201026: 21760.0, 20201027: 20710.0, 20201028: 19760.0, 20201031: 20650.0, 20201101: 20480.0, 20201102: 20010.0, 20201104: 21510.0}
-        , 'py': {20201021: 23610.0, 20201024: 23990.0, 20201026: 22900.0, 20201027: 21800.0, 20201028: 20790.0, 20201031: 20580.0, 20201101: 21540.0, 20201102: 20910.0, 20201104: 20860.0}
-        , 'tno': {20201021: 45582, 20201024: 9270, 20201026: 43019, 20201027: 23360, 20201028: 30277, 20201031: 20359, 20201101: 21310, 20201102: 22337, 20201104: 8953}
-        , 'tval': {20201021: 3561797608680.0, 20201024: 689808784080.0, 20201026: 5372316739110.0, 20201027: 2845911615950.0, 20201028: 2064206435550.0, 20201031: 1681410500120.0, 20201101: 1700893566630.0, 20201102: 1078508781780.0, 20201104: 1759996883990.0}
-        , 'tvol': {20201021: 148496612, 20201024: 30119164, 20201026: 246470643, 20201027: 136913045, 20201028: 100296057, 20201031: 78073449, 20201101: 81345212, 20201102: 51699600, 20201104: 80376009}}
+    assert trade_history.to_csv(line_terminator='\n') == (
+        'date,pc,py,pmin,pmax,tno,tvol,tval\n'
+        '2020-11-04,21900.0,20860.0,21510.0,21900.0,8953,80376009,1759996883990.0\n'
+        '2020-11-02,20860.0,20910.0,20010.0,21490.0,22337,51699600,1078508781780.0\n'
+        '2020-11-01,20910.0,21540.0,20480.0,22000.0,21310,81345212,1700893566630.0\n'
+        '2020-10-31,21540.0,20580.0,20650.0,21600.0,20359,78073449,1681410500120.0\n'
+        '2020-10-28,20580.0,20790.0,19760.0,21420.0,30277,100296057,2064206435550.0\n'
+        '2020-10-27,20790.0,21800.0,20710.0,22050.0,23360,136913045,2845911615950.0\n'
+        '2020-10-26,21800.0,22900.0,21760.0,22700.0,43019,246470643,5372316739110.0\n'
+        '2020-10-24,22900.0,23990.0,22800.0,23730.0,9270,30119164,689808784080.0\n'
+        '2020-10-21,23990.0,23610.0,22660.0,24790.0,45582,148496612,3561797608680.0\n')
 
 
 @patch_get_content('dey.html')
@@ -420,19 +424,11 @@ def test_vskhooz_long():
 @patch_get_content('fmelli_trade_history_top2.txt')
 def test_get_trade_history():
     df = Instrument(1).get_trade_history(2)
-    assert df.to_dict() == {
-        'pmax': {20210120: 10400.0, 20210119: 10380.0}
-        , 'pmin': {20210120: 10120.0, 20210119: 9400.0}
-        , 'pc': {20210120: 10380.0, 20210119: 9910.0}
-        , 'pl': {20210120: 10400.0, 20210119: 10290.0}
-        , 'pf': {20210120: 10350.0, 20210119: 9400.0}
-        , 'py': {20210120: 9910.0, 20210119: 9890.0}
-        , 'tval': {20210120: 498484813880.0, 20210119: 2649416188110.0}
-        , 'tvol': {20210120: 48013394, 20210119: 267389256}
-        , 'tno': {20210120: 7284, 20210119: 36765}}
-    index = df.index
-    assert index.name == 'date'
-    assert all(index.values == [20210120, 20210119])
+    assert df.to_csv(line_terminator='\n') == (
+        'date,pmax,pmin,pc,pl,pf,py,tval,tvol,tno\n'
+        '2021-01-20,10400.0,10120.0,10380.0,10400.0,10350.0,9910.0,498484813880.0,48013394,7284\n'
+        '2021-01-19,10380.0,9400.0,9910.0,10290.0,9400.0,9890.0,2649416188110.0,267389256,36765\n')
+    assert isinstance(df.index, DatetimeIndex)
 
 
 @patch_get_content('vsadid.txt')
